@@ -133,8 +133,8 @@ to find the device path of your keyboard and pass it to the `keyboard` option wh
 
                 ak = dev.active_keys() # get the active keys (keys that are being pressed down)
 
-                # Exit on pressing PAUSE or when all chars have been written.
-                if (event.code == ecodes.KEY_PAUSE) or (char_idx == len(chars)):
+                # Exit on pressing F9 or when all chars have been written.
+                if (event.code == ecodes.KEY_F9) or (char_idx == len(chars)):
                     dev.ungrab() # release the keybaord device so that other applications can receive events
                     break
 
@@ -164,7 +164,9 @@ to find the device path of your keyboard and pass it to the `keyboard` option wh
                             simulate_key_press(ui, ecodes.KEY_LEFTSHIFT)
                             simulate_key_stroke(ui, remapped_code)
                             simulate_key_release(ui, ecodes.KEY_LEFTSHIFT)
-                        # No, then it must be a Unicode char. Is it some sort of unicode arrow?
+                        # No, then it must be a Unicode char. Have I mapped this Unicode char to custom behavior?
+                        elif ord(chars[char_idx]) == 0x2408: # ␈
+                            simulate_key_stroke(ui, ecodes.BACKSPACE)
                         elif ord(chars[char_idx]) == 0x2190: # ←
                             simulate_key_stroke(ui, ecodes.KEY_LEFT)
                         elif ord(chars[char_idx]) == 0x2191: # ↑
